==> ask_sdk_model-1.11.0-py2.py3-none-any.whl: ask_sdk_model/services/game_engine/pattern.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime
    from ask_sdk_model.services.game_engine.input_event_action_type import InputEventActionType


class Pattern(object):
    """
    An object that provides all of the events that need to occur, in a specific order, for this recognizer to be true. Omitting any parameters in this object means \&quot;match anything\&quot;.


    :param gadget_ids: A whitelist of gadgetIds that are eligible for this match.
    :type gadget_ids: (optional) list[str]
    :param colors: A whitelist of colors that are eligible for this match.
    :type colors: (optional) list[str]
    :param action: 
    :type action: (optional) ask_sdk_model.services.game_engine.input_event_action_type.InputEventActionType
    :param repeat: The number of times that the specified action must occur to be considered complete.
    :type repeat: (optional) int

    """
    deserialized_types = {
        'gadget_ids': 'list[str]',
        'colors': 'list[str]',
        'action': 'ask_sdk_model.services.game_engine.input_event_action_type.InputEventActionType',
        'repeat': 'int'
    }  # type: Dict

    attribute_map = {
        'gadget_ids': 'gadgetIds',
        'colors': 'colors',
        'action': 'action',
        'repeat': 'repeat'
    }  # type: Dict

    def __init__(self, gadget_ids=None, colors=None, action=None, repeat=None):
        # type: (Optional[List[object]], Optional[List[object]], Optional[InputEventActionType], Optional[int]) -> None
        """An object that provides all of the events that need to occur, in a specific order, for this recognizer to be true. Omitting any parameters in this object means \&quot;match anything\&quot;.

        :param gadget_ids: A whitelist of gadgetIds that are eligible for this match.
        :type gadget_ids: (optional) list[str]
        :param colors: A whitelist of colors that are eligible for this match.
        :type colors: (optional) list[str]
        :param action: 
        :type action: (optional) ask_sdk_model.services.game_engine.input_event_action_type.InputEventActionType
        :param repeat: The number of times that the specified action must occur to be considered complete.
        :type repeat: (optional) int
        """
        self.__discriminator_value = None  # type: str

        self.gadget_ids = gadget_ids
        self.colors = colors
        self.action = action
        self.repeat = repeat

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, Pattern):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask_sdk_model-1.71.0-py2.py3-none-any.whl: ask_sdk_model/services/game_engine/pattern.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union, Any
    from datetime import datetime
    from ask_sdk_model.services.game_engine.input_event_action_type import InputEventActionType as InputEventActionType_89d7c6e4


class Pattern(object):
    """
    An object that provides all of the events that need to occur, in a specific order, for this recognizer to be true. Omitting any parameters in this object means \&quot;match anything\&quot;.


    :param gadget_ids: A whitelist of gadgetIds that are eligible for this match.
    :type gadget_ids: (optional) list[str]
    :param colors: A whitelist of colors that are eligible for this match.
    :type colors: (optional) list[str]
    :param action: 
    :type action: (optional) ask_sdk_model.services.game_engine.input_event_action_type.InputEventActionType
    :param repeat: The number of times that the specified action must occur to be considered complete.
    :type repeat: (optional) int

    """
    deserialized_types = {
        'gadget_ids': 'list[str]',
        'colors': 'list[str]',
        'action': 'ask_sdk_model.services.game_engine.input_event_action_type.InputEventActionType',
        'repeat': 'int'
    }  # type: Dict

    attribute_map = {
        'gadget_ids': 'gadgetIds',
        'colors': 'colors',
        'action': 'action',
        'repeat': 'repeat'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, gadget_ids=None, colors=None, action=None, repeat=None):
        # type: (Optional[List[object]], Optional[List[object]], Optional[InputEventActionType_89d7c6e4], Optional[int]) -> None
        """An object that provides all of the events that need to occur, in a specific order, for this recognizer to be true. Omitting any parameters in this object means \&quot;match anything\&quot;.

        :param gadget_ids: A whitelist of gadgetIds that are eligible for this match.
        :type gadget_ids: (optional) list[str]
        :param colors: A whitelist of colors that are eligible for this match.
        :type colors: (optional) list[str]
        :param action: 
        :type action: (optional) ask_sdk_model.services.game_engine.input_event_action_type.InputEventActionType
        :param repeat: The number of times that the specified action must occur to be considered complete.
        :type repeat: (optional) int
        """
        self.__discriminator_value = None  # type: str

        self.gadget_ids = gadget_ids
        self.colors = colors
        self.action = action
        self.repeat = repeat

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, Pattern):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
